@@ -8,7 +8,6 @@ import discord
 from ddtrace import tracer
 from discord.embeds import Embed
 from discord.message import Message
-from discord.utils import MISSING
 
 from .. import SpellBot
 from ..models import GameFormat, GameStatus
@@ -116,7 +115,13 @@ class LookingForGameAction(BaseAction):
                 message_xid,
             ):
                 embed = await self.services.games.to_embed()
-                view = StartedGameView(self.bot)
+                fully_seated = await self.services.games.fully_seated()
+                view: Optional[BaseView] = None
+                if fully_seated:
+                    if self.channel_data.get("show_points", False):
+                        view = StartedGameView(bot=self.bot)
+                else:
+                    view = PendingGameView(bot=self.bot)
                 await safe_update_embed(
                     message,
                     embed=embed,
@@ -305,30 +310,16 @@ class LookingForGameAction(BaseAction):
 
         view: Optional[BaseView] = None
         if fully_seated:
-            if await self.services.guilds.should_show_points():
+            if self.channel_data.get("show_points", False):
                 view = StartedGameView(bot=self.bot)
         else:
             view = PendingGameView(bot=self.bot)
 
         if new:  # create the initial game post:
-            # interaction.followup.send() requires that view be MISSING rather than None.
-            view_hack = MISSING if view is None else view
-            if message := await safe_followup_channel(
-                self.interaction,
-                embed=embed,
-                view=view_hack,
-            ):
+            if message := await safe_followup_channel(self.interaction, embed=embed, view=view):
+                await self.services.games.set_message_xid(message.id)
+            elif message := await safe_channel_reply(self.channel, embed=embed, view=view):
                 await self.services.games.set_message_xid(message.id)
-            else:
-                # Somehow the initial game post creation failed, workaround it by
-                # informing users of the issue and just posting directly to the channel.
-                embed.description = (
-                    "**A temporary issue prevented buttons from being added to this game"
-                    " post. To join or leave this game use `/lfg` or `/leave`.**\n\n"
-                    f"{embed.description}"
-                )
-                if message := await safe_channel_reply(self.channel, embed=embed):
-                    await self.services.games.set_message_xid(message.id)
             return
 
         message: Optional[Union[discord.Message, discord.PartialMessage]] = None
@@ -344,24 +335,14 @@ class LookingForGameAction(BaseAction):
             # If it does fail, we will fallback to doing a standard
             # message.edit() call, which should hopefully at least update
             # the game embed, even if the interaction shows as "failed".
-            success = await safe_update_embed_origin(self.interaction, embed=embed, view=view)
-            if success:
+            if await safe_update_embed_origin(self.interaction, embed=embed, view=view):
                 return
 
-        success: bool = False
         if message:
-            success = await safe_update_embed(message, embed=embed, view=view)
-
-        # Somehow the game post update failed, workaround it by informing users
-        # of the issue and just posting directly to the channel.
-        if not success:
-            embed.description = (
-                "**A temporary issue prevented buttons from being added to this game"
-                " post. To join or leave this game use `/lfg` or `/leave`.**\n\n"
-                f"{embed.description}"
-            )
-            if message := await safe_channel_reply(self.channel, embed=embed):
-                await self.services.games.set_message_xid(message.id)
+            if await safe_update_embed(message, embed=embed, view=view):
+                pass
+            elif updated := await safe_channel_reply(self.channel, embed=embed, view=view):
+                await self.services.games.set_message_xid(updated.id)
 
         if not origin:
             await self._reply_found_embed()
@@ -399,26 +380,27 @@ class LookingForGameAction(BaseAction):
             player_xids,
         )
         assert self.interaction.guild
-        for player_xid, new_award in new_roles.items():
-            if player_xid not in fetched_players:
-                warning = (
-                    f"Unable to {'take' if new_award.remove else 'give'}"
-                    f" role {new_award.role}"
-                    f" {'from' if new_award.remove else 'to'}"
-                    f" user <@{player_xid}>"
+        for player_xid, new_awards in new_roles.items():
+            for new_award in new_awards:
+                if player_xid not in fetched_players:
+                    warning = (
+                        f"Unable to {'take' if new_award.remove else 'give'}"
+                        f" role {new_award.role}"
+                        f" {'from' if new_award.remove else 'to'}"
+                        f" user <@{player_xid}>"
+                    )
+                    await safe_followup_channel(self.interaction, warning)
+                    continue
+                player = fetched_players[player_xid]
+                await safe_add_role(
+                    player,
+                    self.interaction.guild,
+                    new_award.role,
+                    new_award.remove,
                 )
-                await safe_followup_channel(self.interaction, warning)
-                continue
-            player = fetched_players[player_xid]
-            await safe_add_role(
-                player,
-                self.interaction.guild,
-                new_award.role,
-                new_award.remove,
-            )
-            await safe_send_user(player, new_award.message)
+                await safe_send_user(player, new_award.message)
 
-        # notifiy issues with player permissions
+        # notify issues with player permissions
         if failed_xids:
             failures = ", ".join(f"<@!{xid}>" for xid in failed_xids)
             warning = f"Unable to send Direct Messages to some players: {failures}"
