@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from asyncio import AbstractEventLoop as Loop
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
 from typing import Optional
@@ -10,7 +9,7 @@ from uuid import uuid4
 
 import discord
 from ddtrace import tracer
-from discord.ext.commands import Bot, CommandError, CommandNotFound, Context
+from discord.ext.commands import AutoShardedBot, CommandError, CommandNotFound, Context
 from expiringdict import ExpiringDict
 
 from .database import db_session_manager, initialize_connection
@@ -23,10 +22,9 @@ from .utils import user_can_moderate
 logger = logging.getLogger(__name__)
 
 
-class SpellBot(Bot):
+class SpellBot(AutoShardedBot):
     def __init__(
         self,
-        loop: Optional[Loop] = None,
         mock_games: bool = False,
         create_connection: bool = True,
     ):
@@ -34,18 +32,16 @@ class SpellBot(Bot):
         intents = discord.Intents().default()
         intents.members = True  # pylint: disable=E0237
         intents.message_content = True  # pylint: disable=E0237
-        logger.info(f"{intents.value=}")
+        logger.info("intents.value: %s", intents.value)
         super().__init__(
             command_prefix="!",
             help_command=None,
-            loop=loop,
             intents=intents,
             application_id=self.settings.BOT_APPLICATION_ID,
         )
         self.mock_games = mock_games
         self.create_connection = create_connection
         self.channel_locks = ExpiringDict(max_len=100, max_age_seconds=3600)  # 1 hr
-        self.event
 
     async def on_ready(self):
         logger.info("client ready")
@@ -149,11 +145,7 @@ class SpellBot(Bot):
                 await message.delete()
 
 
-def build_bot(
-    loop: Optional[Loop] = None,
-    mock_games: bool = False,
-    create_connection: bool = True,
-) -> SpellBot:
-    bot = SpellBot(loop=loop, mock_games=mock_games, create_connection=create_connection)
+def build_bot(mock_games: bool = False, create_connection: bool = True) -> SpellBot:
+    bot = SpellBot(mock_games=mock_games, create_connection=create_connection)
     setup_metrics()
     return bot
