@@ -5,16 +5,16 @@ from pathlib import Path
 from pkgutil import iter_modules
 
 from discord.ext import commands
-from discord.ext.commands import Bot
+from discord.ext.commands import AutoShardedBot
 
 from .about_cog import AboutCog
 from .admin_cog import AdminCog
-from .ban_cog import BanCog
 from .block_cog import BlockCog
 from .config_cog import ConfigCog
 from .events_cog import EventsCog
 from .leave_cog import LeaveGameCog
 from .lfg_cog import LookingForGameCog
+from .owner_cog import OwnerCog
 from .score_cog import ScoreCog
 from .sync_cog import SyncCog
 from .tasks_cog import TasksCog
@@ -27,12 +27,12 @@ logger = logging.getLogger(__name__)
 __all__ = [
     "AboutCog",
     "AdminCog",
-    "BanCog",
     "BlockCog",
     "ConfigCog",
     "EventsCog",
     "LeaveGameCog",
     "LookingForGameCog",
+    "OwnerCog",
     "ScoreCog",
     "SyncCog",
     "TasksCog",
@@ -41,7 +41,7 @@ __all__ = [
 ]
 
 
-async def load_all_cogs(bot: Bot) -> Bot:
+async def load_all_cogs(bot: AutoShardedBot) -> AutoShardedBot:
     # iterate through the modules in the current package
     package_dir = Path(__file__).resolve().parent
     for info in iter_modules([str(package_dir)]):
