@@ -91,6 +91,20 @@ class Channel(Base):
         default="SpellBot Voice Channels",
         server_default=text("'SpellBot Voice Channels'"),
     )
+    delete_expired = Column(
+        Boolean,
+        nullable=False,
+        default=False,
+        server_default=false(),
+        doc="If true delete any expired games rather than updating them to show their expiration.",
+    )
+    show_points = Column(
+        Boolean,
+        nullable=False,
+        default=False,
+        server_default=false(),
+        doc="Configuration for showing points reporting on started games",
+    )
 
     guild = relationship(
         "Guild",
@@ -117,4 +131,6 @@ class Channel(Base):
             "verified_only": self.verified_only,
             "motd": self.motd,
             "voice_category": self.voice_category,
+            "delete_expired": self.delete_expired,
+            "show_points": self.show_points,
         }
