@@ -1,4 +1,6 @@
-# pylint: disable=wrong-import-order
+from __future__ import annotations
+
+from typing import Any
 
 from asgiref.sync import sync_to_async
 
@@ -8,7 +10,7 @@ from ..models import Watch
 
 class WatchesService:
     @sync_to_async
-    def fetch(self, guild_xid: int) -> list[dict]:
+    def fetch(self, guild_xid: int) -> list[dict[str, Any]]:
         watches = (
             DatabaseSession.query(Watch)
             .filter(Watch.guild_xid == guild_xid)
